[![PyPI Version](https://badge.fury.io/py/ucdp-regf.svg)](https://badge.fury.io/py/ucdp-regf)
[![Python Build](https://github.com/nbiotcloud/ucdp-regf/actions/workflows/main.yml/badge.svg)](https://github.com/nbiotcloud/ucdp-regf/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/ucdp-regf/badge/?version=stable)](https://ucdp-regf.readthedocs.io/en/stable/?badge=stable)
[![Coverage Status](https://coveralls.io/repos/github/nbiotcloud/ucdp-regf/badge.svg?branch=main)](https://coveralls.io/github/nbiotcloud/ucdp-regf?branch=main)
[![python-versions](https://img.shields.io/pypi/pyversions/ucdp-regf.svg)](https://pypi.python.org/pypi/ucdp-regf)

# Unified Chip Design Platform - Register File

* [Documentation](https://ucdp-regf.readthedocs.io/en/stable/)
* [PyPI](https://pypi.org/project/ucdp-regf/)
* [Sources](https://github.com/nbiotcloud/ucdp-regf)
* [Issues](https://github.com/nbiotcloud/ucdp-regf/issues)

## Installation

Installing it is pretty easy:

```bash
pip install ucdp-regf
```
